import React, { useState, useEffect } from 'react'
import { routes } from './routes'
import {
  Layout,
  Menu,
  Select,
  Divider,
  Space,
  Button,
  Modal,
  Input,
} from 'antd'
import { Routes, Route, Link, Navigate, useLocation } from 'react-router-dom'
import styled from 'styled-components'
import { SettingFilled, PlusOutlined, ProjectOutlined } from '@ant-design/icons'
const { Content, Sider, Header } = Layout

const SidebarDiv = styled.div`
  .sidebar {
    overflow: auto;
    height: 100vh;
    position: fixed;
    left: 0;
    top: 54px;
    bottom: 0;
  }
  .content {
    overflow: initial;
    margin-left: 200px;
  }
  .header {
    position: fixed;
    z-index: 1;
    width: 100%;
    height: 54px;
    background: #102337;
    display: flex;
    justify-content: flex-end;
    align-items: center;
    .projects {
      color: #fff;
      .ant-select-arrow {
        color: #fff;
      }
    }
    .line {
      height: 24px;
      margin: 0 15px;
      border-left: 1px solid #454545;
    }
    .setting {
      color: #fff;
      font-size: 20px;
      cursor: pointer;
    }
  }
  .headerLogo {
    height: 32px;
    margin: 16px;
    background: rgba(255, 255, 255, 0.2);
    text-align: center;
    color: #fff;
    line-height: 32px;
  }
`
const { Option } = Select

const projects = ['项目1', '项目2', '项目3']

const Main = () => {
  const { pathname } = useLocation()
  const [currentSide, setCurrentSide] = useState('1')
  const [projectsList, setProjectsList] = useState(projects)
  const [isAddProject, setIsAddProject] = useState(false)
  const [projectSetting, setProjectSetting] = useState(false)
  const [projectName, setProjectName] = useState(null)

  const menus = routes.map(item => {
    return {
      key: item.path,
      label: <Link to={item.path}>{item.title}</Link>,
    }
  })
  const openJupyterlab = () => {
    window.open(process.env.REACT_APP_JPT, '_target')
  }
  menus.push({
    key: 'jupyterlab',
    label: <div onClick={openJupyterlab}>可视化编程</div>,
  })

  let childrenList = []
  const routesInfo = routes.map(item => {
    if (item.children.length > 0) {
      childrenList = childrenList.concat(...item.children)
    }
    return {
      path: item.path,
      exact: item?.exact,
      component: item.component,
    }
  })
  const list = routesInfo.concat(...childrenList)

  useEffect(() => {
    setCurrentSide(pathname)
  }, [pathname])

  const onSelectSide = val => {
    setCurrentSide(val.key)
  }

  const addProject = () => {
    setProjectsList([...projectsList, `项目${projectsList.length + 1}`])
    setIsAddProject(false)
    setProjectName(null)
  }

  const handleProjcet = () => {
    setIsAddProject(false)
    setProjectName(null)
  }

  const editProject = () => {
    setProjectSetting(false)
  }

  const addProjectModal = (
    <Modal
      title="新建项目"
      visible={isAddProject}
      onOk={addProject}
      okText="确认添加"
      onCancel={handleProjcet}
      cancelText="取消">
      <Space style={{ padding: '10px 20px 30px' }}>
        <span>项目名称：</span>
        <Input
          value={projectName}
          onChange={e => {
            setProjectName(e.target.value)
          }}
          style={{ width: '350px' }}
        />
      </Space>
    </Modal>
  )

  const projectSettingModal = (
    <Modal
      title="项目设置"
      visible={projectSetting}
      width={'60%'}
      onOk={editProject}
      okText="确认"
      onCancel={() => {
        setProjectSetting(false)
      }}
      cancelText="取消">
      <Space style={{ padding: '10px 20px 30px', display: 'flex' }}>
        <span>项目名称：</span>
        <Input style={{ width: '350px' }} />
      </Space>
      <Space style={{ padding: '10px 20px 30px', display: 'flex' }}>
        <span>项目成员管理：</span>
        <Button type="link">添加成员</Button>
      </Space>
    </Modal>
  )

  return (
    <SidebarDiv>
      <Layout>
        <Header className="header">
        </Header>
        <Layout hasSider style={{ marginTop: '54px' }}>
          <Sider className="sidebar">
            <div className="headerLogo">AI平台</div>
            <Menu
              theme="dark"
              mode="inline"
              items={menus}
              selectedKeys={currentSide}
              onSelect={onSelectSide}
            />
          </Sider>
          <Content className="content">
            <Routes>
              {list.map((route, index) => (
                <Route
                  key={index}
                  path={route.path}
                  exact={route?.exact}
                  element={<route.component />}
                />
              ))}
              <Route path="/" element={<Navigate to="datasource" replace />} />
            </Routes>
          </Content>
        </Layout>
      </Layout>
      {addProjectModal}
      {projectSettingModal}
    </SidebarDiv>
  )
}

export default Main
